@@ -4,8 +4,7 @@ import os
 from dvc.dvcfile import is_valid_filename
 from dvc.exceptions import OutputNotFoundError
 from dvc.path_info import PathInfo
-from dvc.remote.base import RemoteActionNotImplemented
-from dvc.scm.tree import BaseTree
+from dvc.tree.base import BaseTree, RemoteActionNotImplemented
 from dvc.utils import file_md5
 from dvc.utils.fs import copy_fobj_to_file, makedirs
 
@@ -27,7 +26,7 @@ class DvcTree(BaseTree):  # pylint:disable=abstract-method
     """
 
     def __init__(self, repo, fetch=False, stream=False):
-        self.repo = repo
+        super().__init__(repo, {"url": repo.root_dir})
         self.fetch = fetch
         self.stream = stream
 
@@ -44,15 +43,16 @@ class DvcTree(BaseTree):  # pylint:disable=abstract-method
         return outs
 
     def _get_granular_checksum(self, path, out, remote=None):
+        assert isinstance(path, PathInfo)
         if not self.fetch and not self.stream:
             raise FileNotFoundError
         dir_cache = out.get_dir_cache(remote=remote)
         for entry in dir_cache:
-            entry_relpath = entry[out.remote.tree.PARAM_RELPATH]
+            entry_relpath = entry[out.tree.PARAM_RELPATH]
             if os.name == "nt":
                 entry_relpath = entry_relpath.replace("/", os.sep)
             if path == out.path_info / entry_relpath:
-                return entry[out.remote.tree.PARAM_CHECKSUM]
+                return entry[out.tree.PARAM_CHECKSUM]
         raise FileNotFoundError
 
     def open(
@@ -84,8 +84,8 @@ class DvcTree(BaseTree):  # pylint:disable=abstract-method
                 else:
                     checksum = out.checksum
                 try:
-                    remote_info = remote_obj.hash_to_path_info(checksum)
-                    return remote_obj.open(
+                    remote_info = remote_obj.tree.hash_to_path_info(checksum)
+                    return remote_obj.tree.open(
                         remote_info, mode=mode, encoding=encoding
                     )
                 except RemoteActionNotImplemented:
@@ -95,19 +95,19 @@ class DvcTree(BaseTree):  # pylint:disable=abstract-method
 
         if out.is_dir_checksum:
             checksum = self._get_granular_checksum(path, out)
-            cache_path = out.cache.hash_to_path_info(checksum).url
+            cache_path = out.cache.tree.hash_to_path_info(checksum).url
         else:
             cache_path = out.cache_path
         return open(cache_path, mode=mode, encoding=encoding)
 
-    def exists(self, path):
+    def exists(self, path):  # pylint: disable=arguments-differ
         try:
             self._find_outs(path, strict=False, recursive=True)
             return True
         except OutputNotFoundError:
             return False
 
-    def isdir(self, path):
+    def isdir(self, path):  # pylint: disable=arguments-differ
         if not self.exists(path):
             return False
 
@@ -128,12 +128,12 @@ class DvcTree(BaseTree):  # pylint:disable=abstract-method
         # for dir checksum, we need to check if this is a file inside the
         # directory
         try:
-            self._get_granular_checksum(path, out)
+            self._get_granular_checksum(path_info, out)
             return False
         except FileNotFoundError:
             return True
 
-    def isfile(self, path):
+    def isfile(self, path):  # pylint: disable=arguments-differ
         if not self.exists(path):
             return False
 
@@ -155,7 +155,7 @@ class DvcTree(BaseTree):  # pylint:disable=abstract-method
                     download_callback(downloaded)
 
         for entry in dir_cache:
-            entry_relpath = entry[out.remote.tree.PARAM_RELPATH]
+            entry_relpath = entry[out.tree.PARAM_RELPATH]
             if os.name == "nt":
                 entry_relpath = entry_relpath.replace("/", os.sep)
             path_info = out.path_info / entry_relpath
@@ -246,7 +246,7 @@ class RepoTree(BaseTree):  # pylint:disable=abstract-method
     """
 
     def __init__(self, repo, **kwargs):
-        self.repo = repo
+        super().__init__(repo, {"url": repo.root_dir})
         if hasattr(repo, "dvc_dir"):
             self.dvctree = DvcTree(repo, **kwargs)
         else:
@@ -265,7 +265,9 @@ class RepoTree(BaseTree):  # pylint:disable=abstract-method
             return self.dvctree.stream
         return False
 
-    def open(self, path, mode="r", encoding="utf-8", **kwargs):
+    def open(
+        self, path, mode="r", encoding="utf-8", **kwargs
+    ):  # pylint: disable=arguments-differ
         if "b" in mode:
             encoding = None
 
@@ -275,12 +277,14 @@ class RepoTree(BaseTree):  # pylint:disable=abstract-method
             )
         return self.repo.tree.open(path, mode=mode, encoding=encoding)
 
-    def exists(self, path):
+    def exists(
+        self, path, use_dvcignore=True
+    ):  # pylint: disable=arguments-differ
         return self.repo.tree.exists(path) or (
             self.dvctree and self.dvctree.exists(path)
         )
 
-    def isdir(self, path):
+    def isdir(self, path):  # pylint: disable=arguments-differ
         return self.repo.tree.isdir(path) or (
             self.dvctree and self.dvctree.isdir(path)
         )
@@ -288,7 +292,7 @@ class RepoTree(BaseTree):  # pylint:disable=abstract-method
     def isdvc(self, path, **kwargs):
         return self.dvctree is not None and self.dvctree.isdvc(path, **kwargs)
 
-    def isfile(self, path):
+    def isfile(self, path):  # pylint: disable=arguments-differ
         return self.repo.tree.isfile(path) or (
             self.dvctree and self.dvctree.isfile(path)
         )
@@ -392,7 +396,7 @@ class RepoTree(BaseTree):  # pylint:disable=abstract-method
         repo_walk = self.repo.tree.walk(top, topdown=topdown)
         yield from self._walk(dvc_walk, repo_walk, dvcfiles=dvcfiles)
 
-    def walk_files(self, top, **kwargs):
+    def walk_files(self, top, **kwargs):  # pylint: disable=arguments-differ
         for root, _, files in self.walk(top, **kwargs):
             for fname in files:
                 yield PathInfo(root) / fname
@@ -436,5 +440,5 @@ class RepoTree(BaseTree):  # pylint:disable=abstract-method
                     copy_fobj_to_file(fobj, dest_dir / fname)
 
     @property
-    def hash_jobs(self):
+    def hash_jobs(self):  # pylint: disable=invalid-overridden-method
         return self.repo.tree.hash_jobs
